==> alexa-ts-2.3.2.tgz: package/testing.js <==
"use strict";
exports.Fake = Object.freeze({
    timestamp: () => new Date().toISOString(),
    userId: () => "amzn1.ask.account.FAKEACCOUNTID",
    requestId: () => "amzn1.echo-api.request.d15314a4-3a86-4d5a-90b0-5adb6a5b5ce7",
    sessionId: () => "amzn1.echo-api.session.bcea274f-0dd8-43ac-8369-e102f881b42e",
    applicationId: () => "amzn1.ask.skill.659a0b41-d887-45b0-a158-01b3d2214d5a",
    requestBody: (session, request) => ({
        version: '1.0',
        session: session,
        request: request,
    }),
    launchRequest: () => ({
        type: 'LaunchRequest',
        requestId: exports.Fake.requestId(),
        timeStamp: exports.Fake.timestamp(),
    }),
    intentRequest: (intent, slots) => ({
        type: 'IntentRequest',
        requestId: exports.Fake.requestId(),
        timeStamp: exports.Fake.timestamp(),
        intent: {
            name: intent,
            slots: slots || {},
        },
    }),
    session: () => ({
        sessionId: exports.Fake.sessionId(),
        application: {
            applicationId: exports.Fake.applicationId(),
        },
        attributes: {},
        user: {
            userId: exports.Fake.userId(),
            accessToken: null,
        },
        new: true,
    }),
    lambdaContext: () => ({
        awsRequestId: 'e0aa9f2d-5f4a-4ae8-a7b9-bb1a79ed91f6',
        functionName: 'test-function',
        callbackWaitsForEmptyEventLoop: true,
        functionVersion: '$LATEST',
        invokeid: 'invokeid',
        logGroupName: 'logGroupName',
        logStreamName: 'logStreamName',
        memoryLimitInMB: '128',
    }),
});
exports.configure = (handler, lambdaContext) => {
    if (typeof lambdaContext === 'undefined') {
        lambdaContext = exports.Fake.lambdaContext();
    }
    return request => new Promise((resolve, reject) => handler(request, lambdaContext, (err, res) => {
        if (err) {
            reject(err);
        }
        else {
            resolve(res);
        }
    }));
};
const defaultBuilders = () => ({
    LaunchRequest: exports.Fake.launchRequest,
    IntentRequest: exports.Fake.intentRequest,
    Session: exports.Fake.session,
});
const extendBuilders = (custom) => {
    const builders = defaultBuilders();
    if (typeof custom === 'undefined') {
        return builders;
    }
    Object.keys(custom).forEach(key => {
        builders[key] = custom[key];
    });
    return builders;
};
class Session {
    constructor(lambda, builders) {
        this.execute = exports.configure(lambda);
        this.builders = extendBuilders(builders);
        this.session = this.builders.Session();
    }
    LinkAccount(accessToken) {
        this.session.user.accessToken = accessToken;
        return this;
    }
    LaunchSkill() {
        return this.Request(exports.Fake.requestBody(this.session, this.builders.LaunchRequest()));
    }
    RequestIntent(name, slots) {
        return this.Request(exports.Fake.requestBody(this.session, this.builders.IntentRequest(name, slots)));
    }
    Request(request) {
        return this.execute(request).then(response => {
            this.session.new = false;
            if (response.sessionAttributes && Object.getOwnPropertyNames(response.sessionAttributes).length > 0) {
                this.session.attributes = response.sessionAttributes;
            }
            return response;
        });
    }
}
exports.Session = Session;

==> alexa-ts-2.4.1.tgz: package/testing.js <==
"use strict";
exports.Fake = Object.freeze({
    timestamp: () => new Date().toISOString(),
    userId: () => "amzn1.ask.account.FAKEACCOUNTID",
    requestId: () => "amzn1.echo-api.request.d15314a4-3a86-4d5a-90b0-5adb6a5b5ce7",
    sessionId: () => "amzn1.echo-api.session.bcea274f-0dd8-43ac-8369-e102f881b42e",
    applicationId: () => "amzn1.ask.skill.659a0b41-d887-45b0-a158-01b3d2214d5a",
    requestBody: (session, request) => ({
        version: '1.0',
        session: session,
        request: request,
    }),
    launchRequest: () => ({
        type: 'LaunchRequest',
        requestId: exports.Fake.requestId(),
        timeStamp: exports.Fake.timestamp(),
    }),
    intentRequest: (intent, slots) => ({
        type: 'IntentRequest',
        requestId: exports.Fake.requestId(),
        timeStamp: exports.Fake.timestamp(),
        intent: {
            name: intent,
            slots: slots || {},
        },
    }),
    sessionEnded: (reason) => ({
        type: 'SessionEndedRequest',
        reason: reason || 'USER_INITIATED',
        requestId: exports.Fake.requestId(),
        timeStamp: exports.Fake.timestamp(),
    }),
    session: () => ({
        sessionId: exports.Fake.sessionId(),
        application: {
            applicationId: exports.Fake.applicationId(),
        },
        attributes: {},
        user: {
            userId: exports.Fake.userId(),
            accessToken: null,
        },
        new: true,
    }),
    lambdaContext: () => ({
        awsRequestId: 'e0aa9f2d-5f4a-4ae8-a7b9-bb1a79ed91f6',
        functionName: 'test-function',
        callbackWaitsForEmptyEventLoop: true,
        functionVersion: '$LATEST',
        invokeid: 'invokeid',
        logGroupName: 'logGroupName',
        logStreamName: 'logStreamName',
        memoryLimitInMB: '128',
    }),
});
exports.configure = (handler, lambdaContext) => {
    if (typeof lambdaContext === 'undefined') {
        lambdaContext = exports.Fake.lambdaContext();
    }
    return request => new Promise((resolve, reject) => handler(request, lambdaContext, (err, res) => {
        if (err) {
            reject(err);
        }
        else {
            resolve(res);
        }
    }));
};
const defaultBuilders = () => ({
    LaunchRequest: exports.Fake.launchRequest,
    IntentRequest: exports.Fake.intentRequest,
    SessionEndedRequest: exports.Fake.sessionEnded,
    Session: exports.Fake.session,
});
const extendBuilders = (custom) => {
    const builders = defaultBuilders();
    if (typeof custom === 'undefined') {
        return builders;
    }
    Object.keys(custom).forEach(key => {
        builders[key] = custom[key];
    });
    return builders;
};
class Session {
    constructor(lambda, builders) {
        this.execute = exports.configure(lambda);
        this.builders = extendBuilders(builders);
        this.session = this.builders.Session();
    }
    LinkAccount(accessToken) {
        this.session.user.accessToken = accessToken;
        return this;
    }
    LaunchSkill() {
        return this.Request(exports.Fake.requestBody(this.session, this.builders.LaunchRequest()));
    }
    RequestIntent(name, slots) {
        return this.Request(exports.Fake.requestBody(this.session, this.builders.IntentRequest(name, slots)));
    }
    EndSession(reason) {
        return this.Request(exports.Fake.requestBody(this.session, this.builders.SessionEndedRequest(reason)));
    }
    Request(request) {
        return this.execute(request).then(response => {
            this.session.new = false;
            if (response && response.sessionAttributes && Object.getOwnPropertyNames(response.sessionAttributes).length > 0) {
                this.session.attributes = response.sessionAttributes;
            }
            return response;
        });
    }
}
exports.Session = Session;
